( cd usr/lib ; rm -rf libglib-2.0.so.0 )
( cd usr/lib ; ln -sf libglib-2.0.so.0.1800.4 libglib-2.0.so.0 )
( cd usr/lib ; rm -rf libglib-2.0.so )
( cd usr/lib ; ln -sf libglib-2.0.so.0.1800.4 libglib-2.0.so )
( cd usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.1800.4 libgmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.1800.4 libgobject-2.0.so.0 )
( cd usr/lib ; rm -rf libgmodule-2.0.so )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.1800.4 libgmodule-2.0.so )
( cd usr/lib ; rm -rf libgio-2.0.so.0 )
( cd usr/lib ; ln -sf libgio-2.0.so.0.1800.4 libgio-2.0.so.0 )
( cd usr/lib ; rm -rf libgthread-2.0.so )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.1800.4 libgthread-2.0.so )
( cd usr/lib ; rm -rf libgio-2.0.so )
( cd usr/lib ; ln -sf libgio-2.0.so.0.1800.4 libgio-2.0.so )
( cd usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.1800.4 libgthread-2.0.so.0 )
( cd usr/lib ; rm -rf libgobject-2.0.so )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.1800.4 libgobject-2.0.so )
